@@ -9,6 +9,10 @@ def readFile(file):
     return ''
 
 
+def readPackageFile(file):
+    return pkgutil.get_data(__name__, file).decode()
+
+
 def writeFile(file, contents):
     with open(file, 'w') as f:
         f.write(contents)
